/*^^*
 * File:		ATIVideo.h
 *
 * Purpose:		To define the extended APIs for ATI video capture drivers
 *				including:
 * 					ATI Video Basic Drivers Version 2.0
 *					ATI Palindrome Drivers (VT/GT) Version 1.0
 *
 * Copyright (C) December 1995, ATI Technologies Inc.
 *^^*/
#ifndef __ATIVIDEO_H__
#define __ATIVIDEO_H__
/*
 * This file is divided into several parts. The APIs described 
 * herein are intended to be supported on all future capture 
 * products provided by ATI so long as such support is possible
 * on a particular product and under a particular operating 
 * system. The current feature set is/may be applicable to 
 * Windows 3.1, 3.11, Windows '95 and Windows NT running Video 
 * For Windows version 1.1e or equivalent.
 * 
 * This file is divided into several sections which each 
 * describe some aspect of the extended APIs that ATI's capture
 * drivers provide. There is often some overlap between the
 * various APIs and the choice of one or another API is 
 * dependant on the expected application.
 */


/* -------------------------------------------------------------- *
 * Common stuff
 * -------------------------------------------------------------- */
#ifndef _INC_WINDOWS
#include <windows.h>
#endif

#ifndef __MMSYSTEM_H
#include <mmsystem.h> // for definition of mmioFOURCC and some FOURCC's
#endif
/*
 * Some code to handle differences between sending messages
 * in environments like Microsoft's MFC and Borland's OWL.
 */
#ifdef __cplusplus
#define SM(hwnd, msg, wparam, lparam)	::SendMessage(hwnd, msg, wparam, lparam)
extern "C" {
#else
#define SM(hwnd, msg, wparam, lparam)	SendMessage(hwnd, msg, wparam, lparam)
#endif
/*
 * Safe typedef of huge in 32 bit windows.
 */
#ifdef _WIN32
#define huge
#endif

#undef ATIAPI
#define ATIAPI __declspec(dllexport) _stdcall

typedef void huge *	HPVOID; 
typedef BOOL far *	LPBOOL;

/*
 * Constant definitions
 */
#define fccYVU9                 mmioFOURCC( 'Y', 'V', 'U', '9' )		// Planar
#define fccYV12                 mmioFOURCC( 'Y', 'V', '1', '2' )		// Planar
#define fccYVPC                 mmioFOURCC( 'Y', 'V', 'P', 'C' )		// Planar Y (V,U interleaved) 16bpp
#define fccYV16                 mmioFOURCC( 'Y', 'V', '1', '6' )		// Planar
#define fccVYUY                 mmioFOURCC( 'V', 'Y', 'U', 'Y' )		// Packed
#define fccRGB8                 mmioFOURCC( 'R', 'G', 'B', '8' )		// RGB 332
#define fccRG15                 mmioFOURCC( 'R', 'G', '1', '5' )		// RGB 555
#define fccRG16                 mmioFOURCC( 'R', 'G', '1', '6' )		// RGB 565

#define cNTSC	(0)
#define cPAL	(1)
#define cSECAM	(2) 
#define cAUTO	(3)
                   
#define cSmooth	(0)                   
#define cSharp	(1)

#define cCool	(0)
#define cWarm	(1)

#define cOff	(0)
#define cOn		(1)
/*
 * The capture driver registers a video-in-a-window class to simplify
 * these types of application. It's class name is defined as:
 */                                
#define cATIVideoWindowClass	"ATIVideoWindow" 
/*
 * When opening the driver as a non-MSVIDEO client, (i.e. for video
 * in a window, or for tuner functions). We must identify the
 * open as such to prevent the allocation of an MSVIDEO capture
 * channel. To do this, set the OPENTYPE to:
 */                                
#define	OPEN_TYPE_ATILIVEVIDEO	mmioFOURCC('A', 'T', 'I', 'V')
/*
 * For support of multi-card environments, choose any available card this way.
 */
#define	kAnyCard	((WORD)-1)

/* -------------------------------------------------------------- *
 * Video In A Window API
 * -------------------------------------------------------------- *
 * The video in a window API is implemented around a global
 * custom window class. An application creates a child window of
 * this type and sends it a series of messages to control it. The
 * messages are defined below.
 *
 * Note that a set of macros have been provided to 'hide' the
 * messages behind the guise of 'C' functions. This is for
 * convenience only.
 *
 * Note that the VidCreateWindow macro will create a window of the
 * video in a window class as a child of the parent window passed
 * and return a handle  to the newly created window.
 *
 * For still frame capture the wParam is 0 and the lParam points
 * to a buffer which is large enough to hold the captured image in
 * 24 bpp. The image dimensions are stored at the front of this
 * buffer as a RECT structure containing the left edge, top edge, 
 * width, and height of the captured image. The width must be a
 * multiple of 4 bytes. The image is transferred in the same format
 * as a windows DIB (upside down) and will overwrite the rectangle 
 * structure.
 * -------------------------------------------------------------- */

/*
 * Video in a window capabilities
 */
#define	vidZoom				(1L<<0)		// Supports ZOOM IN
#define vidFullScreen		(1L<<1)		// Supports FULLSCREEN via mode switch
#define vidOverlay			(1L<<2)		// Supports OVERLAY (full screen by stretch)
#define vidClosedCaption	(1L<<3)		// Supports Closed Captioning
#define vidStdPAL			(1L<<4)		// Supports PAL sources
#define vidStdNTSC			(1L<<5)		// Supports NTSC sources
#define vidStdSECAM			(1L<<6)		// Supports SECAM sources
#define vidAutoStd			(1L<<7)		// Supports Auto sources
#define vidColors			(1L<<8)		// Supports basic colour controls
#define vidWideTint			(1L<<9)		// Supports wide tint
#define vidTrim				(1L<<10)	// Supports trim (top and bottom)
#define vidPosition			(1L<<11)	// Supports H & V adjust
#define vidConfigure		(1L<<12)	// Supports a config dialog
#define vidCapStill			(1L<<13)	// Can capture still image (any size <=640x480)
#define vidCapClip			(1L<<14)	// Can capture (current size) to clipboard 24bpp
#define vidVBICapture		(1L<<15)	// Can capture VBI data
#define vidCapAltMode		(1L<<24)	// Can do true alternating mode
#define vidCapStill640		(1L<<27)	// Can capture still image at 640x480

#define VidCreateWindow(hwnd, hinst, rect)	\
				CreateWindow(cATIVideoWindowClass, "", \
						WS_CHILD|WS_VISIBLE|WS_CLIPSIBLINGS | WS_CLIPSIBLINGS | WS_CLIPCHILDREN,\
						rect.left, rect.top, \
						rect.right-rect.left, rect.bottom-rect.top, \
						hwnd, NULL, hinst, NULL);
				
#define	VidStartDisplay(hwnd)				(BOOL)SM(hwnd, DVA_START_DISPLAY, 0, 0)
#define	VidStopDisplay(hwnd)				(void)SM(hwnd, DVA_STOP_DISPLAY, 0, 0)
#define	VidConfigure(hwnd)					(void)SM(hwnd, DVA_CONFIGURE, 0, 0)
#define	VidSetFPS(hwnd, fps)				(void)SM(hwnd, DVA_SETFPS, (WORD)fps, 0)
#define	VidGetFPS(hwnd)						(WORD)SM(hwnd, DVA_FPS, 0, 0)
#define	VidSetConnector(hwnd, connector)	(WORD)SM(hwnd, DVA_SETCONNECTOR, (WORD)connector, 0)
#define	VidSetQuality(hwnd, quality)		(void)SM(hwnd, DVA_SETQUALITY, (WORD)quality, 0)
#define	VidSetHandle(hwnd, handle)			(void)SM(hwnd, DVA_SETHANDLE, (WORD)handle, 0)
#define	VidPause(hwnd, state)				(void)SM(hwnd, DVA_PAUSE, (WORD)state, 0)
#define VidCaptureStill(hwnd, buffer)		(BOOL)SM(hwnd, DVA_CAPTURESTILL, 0, (LPARAM)buffer)
#define	VidGetNumCards(hwnd, value)			(WORD)SM(hwnd, DVA_GETNUMCARD, FALSE, 0)
#define	VidGetCaps(hwnd)					(DWORD)SM(hwnd, DVA_GETCAPS, 0, 0)
#define	VidSetZoom(hwnd, lpRect)			(BOOL)SM(hwnd, DVA_SETZOOM, 0, (LPARAM)(LPRECT)lpRect)
#define	VidSetFullScreen(hwnd, bFull)		(BOOL)SM(hwnd, DVA_SETFULL, bFull, 0)
#define	VidSetCC(hwnd, hwndHook, dwID)		(BOOL)SM(hwnd, DVA_SETCC, (WPARAM)hwndHook, (LPARAM)dwID)
#define VidCaptureClipboard(hwnd)			(BOOL)SM(hwnd, DVA_CAPTURECLIP, 0, 0)
#define VidCaptureTrue640Clipboard(hwnd)	(BOOL)SM(hwnd, DVA_CAPTURETRUECLIP, 0, 0)

#define VidSetBrightness(hwnd, value)		(WORD)SM(hwnd, DVA_SET_BRIGHTNESS, TRUE, value)
#define VidSetContrast(hwnd, value)			(WORD)SM(hwnd, DVA_SET_CONTRAST, TRUE, value)
#define VidSetColor(hwnd, value)			(WORD)SM(hwnd, DVA_SET_COLOR, TRUE, value)
#define VidSetTint(hwnd, value)				(int) SM(hwnd, DVA_SET_TINT, TRUE, value)
#define VidSetHAdjust(hwnd, value)			(int) SM(hwnd, DVA_SET_HADJUST, TRUE, value)
#define VidSetVAdjust(hwnd, value)			(int) SM(hwnd, DVA_SET_VADJUST, TRUE, value)
#define VidSetTracking(hwnd, value)			(WORD)SM(hwnd, DVA_SET_TRACKING, TRUE, value)
#define VidSetSharpness(hwnd, value)		(WORD)SM(hwnd, DVA_SET_SHARPNESS, TRUE, value)
#define VidSetStandard(hwnd, value)			(WORD)SM(hwnd, DVA_SET_STANDARD, TRUE, value)
#define VidSetTrim(hwnd, value)				(WORD)SM(hwnd, DVA_SET_TRIM, TRUE, value)
#define VidSetColorTemp(hwnd, value)		(WORD)SM(hwnd, DVA_SET_COLORTEMP, TRUE, value)
#define	VidSetCard(hwnd, value)				(WORD)SM(hwnd, DVA_SET_CARD, TRUE, value)
#define	VidSetFields(hwnd, value)			(WORD)SM(hwnd, DVA_SET_FIELD, TRUE, value)

#define VidGetBrightness(hwnd)				(WORD)SM(hwnd, DVA_SET_BRIGHTNESS, FALSE, 0)
#define VidGetContrast(hwnd)				(WORD)SM(hwnd, DVA_SET_CONTRAST, FALSE, 0)
#define VidGetColor(hwnd)					(WORD)SM(hwnd, DVA_SET_COLOR, FALSE, 0)
#define VidGetTint(hwnd)					(int) SM(hwnd, DVA_SET_TINT, FALSE, 0)
#define VidGetHAdjust(hwnd)					(int) SM(hwnd, DVA_SET_HADJUST, FALSE, 0)
#define VidGetVAdjust(hwnd)					(int) SM(hwnd, DVA_SET_VADJUST, FALSE, 0)
#define VidGetTracking(hwnd)				(WORD)SM(hwnd, DVA_SET_TRACKING, FALSE, 0)
#define VidGetSharpness(hwnd)				(WORD)SM(hwnd, DVA_SET_SHARPNESS, FALSE, 0)
#define VidGetStandard(hwnd)				(WORD)SM(hwnd, DVA_SET_STANDARD, FALSE, 0)
#define VidGetTrim(hwnd)					(WORD)SM(hwnd, DVA_SET_TRIM, FALSE, 0)
#define VidGetColorTemp(hwnd)				(WORD)SM(hwnd, DVA_SET_COLORTEMP, FALSE, 0)
#define	VidGetCard(hwnd)					(WORD)SM(hwnd, DVA_SET_CARD, FALSE, 0)
#define	VidGetFields(hwnd, value)			(WORD)SM(hwnd, DVA_SET_FIELD, FALSE, 0)
#define	VidSetVBI(hwnd, state, lpFailure)	(BOOL)SM(hwnd, DVA_SETVBI, (WPARAM)state, (LPARAM)lpFailure)

/* 
 * User messages and class name definition for live video in a window
 * API. Unless otherwise noted, wParam and lParam must be set to zero
 * for each of these messages. Typically these values do not need to
 * be accessed directly.
 */
#define DVA_MMTIMERTICK		(WM_USER+1)		// Internal (private)
#define DVA_SETHANDLE		(WM_USER+2)		// Internal (private)
#define DVA_START_DISPLAY	(WM_USER+3)		// Begin transferring frames,
#define DVA_STOP_DISPLAY	(WM_USER+4)		// Halt transferring  frames
#define DVA_CONFIGURE		(WM_USER+5)		// Invoke configuration dialog
#define DVA_SETFPS			(WM_USER+6)		// Set target frame rate, wParam contains target frame rate.
#define DVA_FPS				(WM_USER+7)		// Query current actual frame rate (returns WORD f per 100s)
#define DVA_SETCONNECTOR	(WM_USER+8)		// Set connector, wParam contains new value, returns prev. value.
#define DVA_SETQUALITY		(WM_USER+9)		// Choose between speed/quality, wParam is BOOL true for quality.
#define DVA_CAPTURESTILL	(WM_USER+10)	// Grab a still frame at 24bpp (see notes below)
#define DVA_PAUSE				(WM_USER+11)	// Pause video playback  
#define DVA_GETNUMCARDS		(WM_USER+12)	// Returns the number of capture cards available.
#define DVA_GETCAPS			(WM_USER+13)	// Get the current capabilities
#define DVA_SETZOOM			(WM_USER+14)	// Set the current zoom ratio as a fraction of a 640x480 window.
#define DVA_SETFULL			(WM_USER+15)	// Set the current full screen state based on wParam
#define DVA_SETCC				(WM_USER+16)	// Set the current window to recieve CC data.
#define DVA_CAPTURECLIP		(WM_USER+17)	// Grab current frame at 24bpp to clipboard
#define DVA_CAPTURETRUECLIP (WM_USER+18)	// Grab 640x480 frame at 24bpp to clipboard
#define DVA_SETVBI			(WM_USER+19)	// Set the current window to recieve VBI data.

#define DVA_CCCALLBACK		(WM_USER+43)	// Message send to window to display CC data.
#define DVA_PAUSE_PROCESS  (WM_USER+44)   // Internal (private)
#define DVA_RESUME_PROCESS (WM_USER+45)   // Internal (private)

#define	VBI_CHANGE_MASK	(WM_USER + 46)	// Internal message as a response to Intel's VxD call back
#define	VBI_FAILURE			(WM_USER + 47)	// Internal message to show a VBI failure reason
#define DVA_CREATE_TRANSFER (WM_USER+48)   // Internal (private)
/*
 * For the following messages, the new value is sent as the lParam
 * and wParam is boolean TRUE to set the value, FALSE to just retreive
 * the value.
 */
#define DVA_SET_BRIGHTNESS	(WM_USER+20)	// Set/Get the current brightness adjustment
#define DVA_SET_CONTRAST	(WM_USER+21)	// Set/Get the current contrast adjustment.
#define DVA_SET_COLOR		(WM_USER+22)	// Set/Get the current color adjustment.
#define DVA_SET_TINT		(WM_USER+23)	// Set/Get the current tint adjustment.
#define DVA_SET_HADJUST		(WM_USER+24)	// Set/Get the current h-pos adjustment.
#define DVA_SET_VADJUST		(WM_USER+25)	// Set/Get the current v-pos adjustment.
#define DVA_SET_TRACKING	(WM_USER+26)	// Set/Get the current tracking adjustment.
#define DVA_SET_SHARPNESS	(WM_USER+27)	// Set/Get the current sharpness adjustment.
#define DVA_SET_STANDARD	(WM_USER+28)	// Set/Get the current standard adjustment.
#define DVA_SET_TRIM		(WM_USER+29)	// Set/Get the current trim capture adjustment.
#define DVA_SET_COLORTEMP	(WM_USER+30)	// Set/Get the current color temp. adjustment.
#define DVA_SET_CARD		(WM_USER+31)	// Set/Get the preferred card for video input.											
#define DVA_SET_FIELD		(WM_USER+32)	// Set/Get the number of fields to capture

/* -------------------------------------------------------------- *
 * General Driver Access
 * -------------------------------------------------------------- *
 * The following functions appear specifically in DVAAPI.c which
 * should be compiled and linked into any program wishing to
 * access the ATI capture driver directly. The function DVALoad()
 * is used to gain access to all entry points and functions in
 * the driver. The function DVAFree() is used to unhook and load
 * the driver.
 * -------------------------------------------------------------- */
BOOL  ATIAPI			DVALoad				(HINSTANCE hInstance);
void 	ATIAPI		DVAFree				(void);

/* -------------------------------------------------------------- *
 * Direct Video Access
 * -------------------------------------------------------------- *
 * These functions provide direct access to the capture engine in
 * the driver without any of the overhead or benefits of the VFW
 * capture engine. These functions are very low level allowing the
 * caller capture images in arbitrary sizes and formats directly
 * from host memory to a caller supplied memory buffer.
 * -------------------------------------------------------------- */

typedef	DWORD	HDVA;	// Handle to a DVA capture channel

/*
 * DVA functional capabilities descriptions. These are returned
 * by the DVAGetCaps function to determine the capabilities of
 * the current driver. All unused bits are reserved for future
 * features and formats and should be ignored if not defined.
 * (i.e.: they will be zero until we define them as something
 * else.)
 *
 * The LOWORD contains formats, HIWORD contains features
 *
 *          Capability   Value     <dwFormat>
 */
#define		dvaRGB8		(1L<<0)	// fccRGB8
#define		dvaRGB555	(1L<<1)	// fccRG15
#define		dvaRGB565	(1L<<2)	// fccRG16
#define		dvaRGB24	(1L<<3)	// fccRG24
#define		dvaYUV9		(1L<<4)	// fccYVU9
#define		dvaYUV12	(1L<<5)	// fccYV12
#define		dvaYVPC		(1L<<6)	// fccYVPC
#define		dvaVYUY		(1L<<7)	// fccYVUY
#define		dvaYUV16	(1L<<8)	// fccYV16
#define		dvaYUYV		(1L<<9)	// fccYUYV

#define		dvaCrop			(1L<<16)
#define		dvaScaleUp		(1L<<17)
#define		dvaScaleDn		(1L<<18)
#define		dvaFormNTSC		(1L<<19)
#define		dvaFormPAL		(1L<<20)
#define		dvaFormSECAM	(1L<<21)
#define		dvaFormAuto		(1L<<22)     
#define		dvaTint45Deg	(1L<<23)

/* -------------------------------------------------------------- *
 * DVA Capture Functions Group
 * -------------------------------------------------------------- *
 *
 * Retreive the capabilities of the currently connected driver
 */
DWORD ATIAPI	DVAGetCaps			(WORD wCard);
/*
 * Create a handle to a capture channel in a specific format
 * lprcImage is used to size the capture channel, always set
 * the top left to (0,0). Capture channels are double buffered
 * (if possible) and use only a single field if the capture
 * height is less than 240 pixel. Interlaced otherwise.
 *
 * DVA supports the 'concept' of more than one capture card
 * (although it may not actually support more than one card)
 * Typically use <kAnyCard> for <wCard> to connect to any
 * available card.
 */
HDVA ATIAPI		DVAMakeCapture		(WORD wCard, LPRECT lprcImage, DWORD dwFormat);
/*
 * Release a capture aquired through DVAMakeCapture
 * Passing NULL for hCapture is safe.
 */
void ATIAPI		DVAFreeCapture		(HDVA hCapture);
/*
 * If the capture handle was allocated as <kAnyCard> then
 * this function can be used to determine the actual card
 * that was used.
 */
WORD ATIAPI		DVAGetCard			(HDVA hCapture);
/*
 * Check to see if a capture has completed. Returns TRUE if
 * a frame of video is ready to be transferred to host memory,
 * FALSE if no capture has been started or the current capture
 * is not yet complete.
 */
BOOL ATIAPI		DVACheckCapture		(HDVA hCapture);
/*
 * Capture a frame. This function uses the provided capture
 * handle to specify the capture and transfer of video data.
 * It is possible that each call to this function does NOT
 * return a frame of video data, in the case of double buffered
 * capture, (the default) the first call to DVACapture()
 * triggers the initial capture and tracks the buffer but does
 * not return a video frame. Subsequent calls will return a
 * video frame.
 */
WORD ATIAPI		DVACapture			(HDVA hCapture, HPVOID hpNextBuffer);
/*
 * Specify a cropping rectangle within the original capture window
 * to capture. <lprcCrop> must be bounded by <lprcImage> provided
 * during DVAMakeCapture(). Passing NULL for <lprcCrop> removes
 * any cropping so far provided. Buffers passed to DVACapture
 * in future need only be large enough to contain the pixels
 * bounded by <lprcCrop>. After a successful call to DVASetCrop()
 * the video capture must be 'restarted' with a call to DVACapture()
 * in the same manner as the first DVACapture() call.
 */
BOOL ATIAPI		DVASetCrop			(HDVA hCapture, LPRECT lprcCrop);
/*
 * Request that the driver display a configuration dialog
 * which allows customer support to determine what modules
 * are installed and functioning.
 */
WORD  ATIAPI DVAVfwSetCC(WORD wCard, BOOL fCCOn, HWND hwndClient, UINT Msg, DWORD dwId);
 
void ATIAPI		DVAShowConfig			(WORD wCard);
int  ATIAPI 	DVATuneSetList			(WORD wCard, DWORD lpTunerFormatList, BOOL fCableOrAir); 
BOOL ATIAPI 	DVATunerChannelSurfing	(WORD wCard, BOOL fSwitch);

/* -------------------------------------------------------------- *
 * DVA VBI functions Group
 * -------------------------------------------------------------- *
 */
typedef enum {
	VBI_DISCONNECT = 0,
	VBI_CONNECT,
	VBI_OFF,
	VBI_PAUSE,
	VBI_ON,
} VBI_STATE;

typedef struct
{
	LPSTR lpszFailureString;		// buffer to put the failure description
	WORD wStringLength;				// in - buffer length
									// out - number of bytes actually transferred
} VBIFAILURE, *PVBIFAILURE, FAR * LPVBIFAILURE;

/* -------------------------------------------------------------- *
 * DVA Property Functions Group
 * -------------------------------------------------------------- *
 *
 * There are a number of properties that are set
 * on a per card basis. For these use the 
 * DVASetProperty() and DVAGetProperty() functions.
 *
 * The following defines the properties which
 * may be accessed with these functions.
 */
typedef enum  {
	// Symbol		   Valid Range
	kDNumCards = 0,	// (Get only)
	kDBrightness,	// 0 - 200 %
	kDContrast,		// 0 - 200 %
	kDTint,			// -180 - 180 degrees
	kDColor,		// 0 - 200 %
	kDHAdjust,		// -50 - 50
	kDVAdjust,		// -50 - 50
	kDTracking,		// 0, 1, 2
	kDSharpness,	// 0=Smooth, 1=Sharp
	kDStandard,		// 0=NTSC, 1=PAL
	kDColorTemp,	// 0=Cool, 1=Warm
	kDTrim,			// 0=Off, 1=On
	kDConnector,	// 0, 1, 2
	kDFields,		// 0=Even, 1=Odd, 2=Both
} DVAProperty;

/*
 * ...and these protoypes define how to access these properties.
 */
void ATIAPI		DVASetProperty		(WORD wCard, DVAProperty wProperty, DWORD dwNewValue);
DWORD ATIAPI	DVAGetProperty		(WORD wCard, DVAProperty wProperty);
/*
 * This function is used to enumerate the connectors on the card...
 */
BOOL ATIAPI		DVAEnumConnectors	(WORD wCard, WORD wIndex, WORD far *lpwInfo);
/*
 * The <lpwInfo> field in the above function returns the following.
 * Multi-function connectors will set more than 1 of these bits flags
 */
#define	CON_TUNER			(1<<0)
#define CON_SENSE_TUNER		(1<<1)
#define CON_SVIDEO			(1<<2)
#define CON_SENSE_SVIDEO	(1<<3)
#define CON_COMP			(1<<4)
#define CON_SENSE_COMP		(1<<5)

/* -------------------------------------------------------------- *
 * DVA Tuner Functions Group
 * -------------------------------------------------------------- */
#define kUseAntenna			(0)
#define kUseCATV			(1)
#define kUseIRC_CATV		(2)
#define kUseHRC_CATV		(3)


#define kUseNTSC			(0)
#define kUsePAL				(1)
#define kUseSECAM			(2)

#define kChannel			(0)
#define kVolume				(1)
#define kCable				(2)
#define kSignal				(3)

#define kFeatureTuner		(0)
#define kFeatureAudio		(1)

/*
 * The following are the tuner capabilities bits.
 * They are repeated 3 times once for NTSC in byte 0
 * once for PAL in byte 1, once for SECAM in byte 2.
 * Definintions for NTSC, PAL, and SECAM occur earlier
 * in this file.
 */
#define	kOFFAIR				(1<<0)
#define	kCABLE				(2<<0)
#define kCANDETECT			(3<<0)	// private internal value

#ifndef TUNERCALLBACK
typedef WORD (CALLBACK *TUNERCALLBACK)(WORD wCurrent, WORD wMaximum, WORD wFound);
#endif

/*
 * The following functions provide access to tuners of an ATI capture product.
 *
 * Note:
 * Current drivers only support 1 tuner card so this value should be set to 0
 *
 * The caps function returns the capabilities of the tuner installed on the card
 * a return value of 0 indicates that no tuner is available.
 */
DWORD ATIAPI	DVATuneCaps			(WORD wCard);
/*
 * This Channels function returns the maximum and minimum channel number that
 * is available for the current signal format (NTSC...) and standard (AIR...).
 * The HIWORD of the return value is the maximum channel, the LOWORD is the
 * minimum channel.
 */
DWORD ATIAPI	DVATuneChannels		(WORD wCard);
/*
 * The AutoScan function invokes a callback with progress information as it scans.
 * The callback function should have the prototype
 *
 * void FAR PASCAL TunerCallback(WORD wCurrentChannel, WORD wMaxChannel, WORD wFound);
 *
 * wFound is 0 if no channel present or 1 if the current channel is active. The function
 * returns the number of channels found.
 */	
WORD ATIAPI	DVATuneScan			(WORD wCard, TUNERCALLBACK lpfnCallback);
/*
 * The following function allows the application to request a
 * specific channel be tuned. The result is the newly selected channel.
 * Illegal channel numbers are ignored.
 */
WORD ATIAPI	DVATuneSetChannel	(WORD wCard, WORD wChannel);
/*
 * The following allows for the selection of various cable
 * standards. To determine the name and allowable <wType>
 * values see DVATuneEnumFormat (below).
 */	
WORD ATIAPI	DVATuneSetCable		(WORD wCard, WORD wType);
/*
 * The following allows for the selection of NTSC, PAL, or SECAM.
 * Pass 0 to select NTSC, etc.. The return value is the newly selected state.
 */	
WORD ATIAPI	DVATuneSetStandard	(WORD wCard, WORD wStandard);
/*
 * The following allows for the enumeration of supported formats.
 * Pass <wIndex> to determine if a particular index is valid (start
 * at 0). On return of TRUE, lpbIsCable will be TRUE for cable signals,
 * and lpName will contain the name of the format. lpName must be 32 bytes.
 */	
BOOL ATIAPI	DVATuneEnumFormat	(WORD wCard, WORD wIndex, BOOL far *lpfIsCable, WORD far *lpwStd, LPBYTE lpName);
/*
 * The following allows for fine tuning of <wChannel>, <bOffset> is a signed
 * fine tuning amount.
 */	
WORD ATIAPI	DVATuneFineTune		(WORD wCard, WORD wChannel, BYTE bOffset);
/*
 * The following gets the current status of the tuner lock
 * after the last channel has been set
 */	
#define TUNER_LOCK_FALSE	FALSE
#define TUNER_LOCK_TRUE		TRUE
#define TUNER_LOCK_UNKNOWN	0xFFFF

WORD ATIAPI	DVATuneGetLockStatus ( WORD wCard, WORD wChannel);

/* -------------------------------------------------------------- *
 * DVA Audio Functions Group
 * -------------------------------------------------------------- *
 *
 * Audio capabilities bits
 */
#define SND_CANMIX			(1<<0)
#define SND_CANSWITCH		(1<<1)
#define SND_STEREO			(1<<2)      
#define SND_DETECT_STEREO	(1<<3)		// Tuner support stereo audio and detection.
/*
 * All audio volumes are in the range 0 to 1000 with 0 being muted.
 */
#define SND_CAN_VOLUME_CNTL		(1<<4)
#define SND_EXTERNAL_LINE_IN	(1<<5)       
#define SND_CAN_HW_MUTE			(1<<6)      
#define SND_CAN_SAP				(1<<7)      
/*
 * Retrieve audio capabilities
 */
DWORD ATIAPI	DVAAudioCaps			(WORD wCard);
/*
 * Set stereo volume. If card does not support stereo, left and right 
 * channels are averaged. Return value as DVAGetAudioVolume()
 */
DWORD ATIAPI	DVAAudioSetStereoVolume	(WORD wCard, WORD wLVolume, WORD wRVolume);
/*
 * Set volume. If card supports stereo, left and right channels 
 * are the same. Return value as DVAGetAudioVolume()
 */
DWORD ATIAPI	DVAAudioSetVolume		(WORD wCard, WORD wVolume);
/*
 * Get audio volume. Left volume in HIWORD, right volume in LOWORD
 * Non-stereo solutions report same volume in left and right channel.	
 */
DWORD ATIAPI	DVAAudioGetVolume		(WORD wCard);
/*
 * Set mix ratio between pass-through and tuner audio. 0 is 100%
 * pass-through, 500 is 50/50 split, 1000 is 100% tuner.
 */
DWORD ATIAPI	DVAAudioSetMix			(WORD wCard, WORD wMix);
/*
 * Set switch between Tuner, pass-through, FM or MUTE
 * pass-through, TRUE selects tuner.
 */
DWORD ATIAPI	DVAAudioSetSwitch		(WORD wCard, WORD bSwitch);
/*
 * On cards which report 'SND_DETECT_STEREO' this function is used
 * to access that ability.
 */
BOOL ATIAPI		DVAAudioDetectStereo	(WORD wCard);
/*
 * Set internal(CD) or external(Line In) connector
 */
WORD ATIAPI 	DVASndSetExternal		(WORD wCard, BOOL fSwitch) ;
/*
 * Mutes\Unmutes Hardware
 */
BOOL ATIAPI     DVAAudioSetMute			(BOOL bMute);
/*
 * Sets MAIN or SAP audio Channel 0=MAIN, 1=SAP
 */
DWORD ATIAPI	DVAAudioSetChannel		(WORD wCard,DWORD dwMode);
/*
 * Detects Stereo or SAP modes
 */
#define SND_STEREO_MODE_DETECTED	(1<<0)
#define SND_SAP_MODE_DETECTED		(1<<1)

DWORD ATIAPI	DVAAudioDetectStatus	(WORD wCard);

/*
 * Get number of sound drivers in the system
 */
WORD ATIAPI		DVAAudioDrivers			(void);
/*
 * Get the human readable description of the sound driver
 */
BOOL ATIAPI		DVAAudioEnumDrivers		(WORD wAVDriver, LPSTR lpName);
/*
 * Get the number of connectors for the sound card
 */
WORD ATIAPI		DVAAudioConnector		(WORD wAVDriver);
/*
 * Get the human readable description of the connector
 */
BOOL ATIAPI		DVAAudioEnumConnector	(WORD wAVDriver, WORD wConnector, LPSTR lpName);
/*
 * Select a particular sound card connector
 */
DWORD ATIAPI	DVAAudioSetConnector	(WORD wAVDriver, WORD wConnector, WORD wRecLevel);
/*
 * Get current record level
 */
WORD ATIAPI		DVAAudioGetRecordLevelConnector(WORD wAVDriver, WORD wConnector);

#ifdef __cplusplus
};
#endif
	
#endif

